cmd/ejobs: rename from jobs

There is already a `jobs` shell builtin. Rename this command to avoid
confusion.

Change-Id: I9e8a6f36ceb4a095b9a24adb723e82162a1ddd0a
Reviewed-on: https://go-review.googlesource.com/c/pkgsite-metrics/+/499315
Run-TryBot: Jonathan Amsterdam <jba@google.com>
Reviewed-by: Zvonimir Pavlinovic <zpavlinovic@google.com>
TryBot-Result: Gopher Robot <gobot@golang.org>
diff --git a/cmd/jobs/main.go b/cmd/ejobs/main.go
similarity index 98%
rename from cmd/jobs/main.go
rename to cmd/ejobs/main.go
index cdc99a7..f0f6b82 100644
--- a/cmd/jobs/main.go
+++ b/cmd/ejobs/main.go
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
 // Command jobs supports jobs on ecosystem-metrics.
 package main
 
 import (
@@ -57,7 +57,7 @@
 		out := flag.CommandLine.Output()
 		fmt.Fprintln(out, "usage:")
 		for _, cmd := range commands {
-			fmt.Fprintf(out, "  job %s %s\n", cmd.name, cmd.argdoc)
+			fmt.Fprintf(out, "  ejobs %s %s\n", cmd.name, cmd.argdoc)
 			fmt.Fprintf(out, "\t%s\n", cmd.desc)
 		}
 		fmt.Fprintln(out, "\ncommon flags:")
@@ -2,7 +2,7 @@
 // license that can be found in the LICENSE file.
 
-// Command jobs supports jobs on ecosystem-metrics.
+// Command ejobs supports jobs on ecosystem-metrics.
 package main
 